Get the contrastive PCA factors
get_c_pca_factors.RdGetter function for the feature factors of the contrastive PCA
Arguments
- object
The underlying class, see
BulkCoExp().
get_c_pca_factors.RdGetter function for the feature factors of the contrastive PCA
The underlying class, see BulkCoExp().