Get the contrastive PCA loadings
get_c_pca_loadings.RdGetter function for the feature loadings of the contrastive PCA
Arguments
- object
The underlying class, see
BulkCoExp().
get_c_pca_loadings.RdGetter function for the feature loadings of the contrastive PCA
The underlying class, see BulkCoExp().