Return the metadata
get_metadata.RdGetter function to extract the metadata from the BulkCoExp() or
BulkDge().
Arguments
- object
The underlying object, either
BulkCoExp()orBulkDge().- ...
Additional arguments to parse to the functions.
get_metadata.RdGetter function to extract the metadata from the BulkCoExp() or
BulkDge().
The underlying object, either BulkCoExp() or
BulkDge().
Additional arguments to parse to the functions.