Get the ready obs data from various sub method
get_obs_data.RdHelper method that creates data.tables with cell indices which were used in the given analysis + the values that are to be added to the obs table in the DuckDB.
Usage
get_obs_data(x, ...)
# S3 method for class 'ScListRes'
get_obs_data(x, ...)
# S3 method for class 'ScMatrixRes'
get_obs_data(x, columns = NULL, ...)
# S3 method for class 'ScrubletRes'
get_obs_data(x, ...)
# S3 method for class 'BoostRes'
get_obs_data(x, ...)
# S3 method for class 'ScDblFinderRes'
get_obs_data(x, ...)
# S3 method for class 'SingleCellFastClusters'
get_obs_data(x, ...)