Return the outputs
get_outputs.RdGetter function to extract the outputs from the BulkCoExp() or
BulkDge().
Arguments
- object
The underlying object, either
BulkCoExp()orBulkDge().- ...
Additional arguments to parse to the functions.
get_outputs.RdGetter function to extract the outputs from the BulkCoExp() or
BulkDge().
The underlying object, either BulkCoExp() or
BulkDge().
Additional arguments to parse to the functions.