Skip to contents

Get the final results from BixverseBaseClass class (or child classes).

Usage

get_results(object)

Arguments

object

The underlying BixverseBaseClass() class. The class functionality is usually inherited by other S7 classes in bixverse.

Value

Returns the final results if any have been stored in the class.