Helper function to generate default parameters for the fast clustering for the doublet detection methods
params_fast_cluster_default.RdHelper function to generate default parameters for the fast clustering for the doublet detection methods
Value
A named list with the following elements:
km_type - String. The type of k-means clustering. One of
c("minibatch", "standard"). Defaults to"minibatch".n_centroids - Integer or
NULL. The number of centroids to use.NULLusessqrt(N_cells) * 4centroids. Defaults toNULL.kmeans_iters - Integer. Number of maximum k-means iterations. Defaults to
100L.batch_size - Integer. Max batch size, capped at
N_cells / 2depending on the data set. Defaults to4098L.