Skip to contents

[Experimental] Ranks the columns of a matrix with the tie method.

Usage

rs_rank_matrix_col(exp)

Arguments

exp

Numerical matrix. The expression matrix (rows = genes, columns = samples).

Value

Returns a matrix of ranks with the same shape as exp.