Skip to contents

This function calculates the Jaccard or similarity index between a two given string vector and a of other string vectors.

Usage

rs_set_similarity(s_1, s_2, overlap_coefficient)

Arguments

s_1

The String vector against which to calculate the set similarities.

s_2

The String vector against which to calculate the set similarities.

overlap_coefficient

Boolean. Use the overlap coefficient instead of the Jaccard similarity be calculated.