This function calculates the set similarity via Jaccard or overlap
coefficient across all permutations of one list.
Usage
rs_set_similarity_list(list, overlap_coefficient)
Arguments
- list
A named R list.
- overlap_coefficient
Boolean. Use the overlap coefficient instead of
the Jaccard similarity.
Value
A list with the following items, one entry per unordered pair: