Skip to contents

Wraps find_hvg_sc() as an ScStep.

Usage

step_hvg_sc(
  hvg_no = 2000L,
  hvg_params = params_sc_hvg(),
  streaming = NULL,
  .verbose = TRUE
)

Arguments

hvg_no

Integer. Number of highly variable genes to include. Defaults to 2000L.

hvg_params

List, see params_sc_hvg(). This list contains

  • method - Which method to use. One of c("vst", "meanvarbin", "dispersion")

  • loess_span - The span for the loess function to standardise the variance

  • num_bin - Integer. Not yet implemented.

  • bin_method - String. One of c("equal_width", "equal_freq"). Not implemented yet.

streaming

Optional Boolean. Shall the data be streamed in. Useful for larger data sets where you wish to avoid loading in the whole data. If NULL, will automatically detect. Not used for MetaCells.

.verbose

Boolean or integer. Controls verbosity and returns run times. FALSE -> quiet, TRUE or 1L -> normal verbosity, 2L -> detailed verbosity.

Value

An ScStep.

Examples

# a step is inert until the pipeline is applied
step_hvg_sc(hvg_no = 30L)
#> <ScStep> hvg(hvg_no = 30L, hvg_params = <list>, streaming = NULL, .verbose = TRUE)