Skip to contents

Generic base class that is used for inheritance in certain common methods across other classes.

Usage

BixverseBaseClass()

Value

Returns the S7 object for further operations.

Properties

params

A (nested) list that will store all the parameters of the applied function.

final_results

A data.table that will contain the final results.