Bulk RNAseq co-expression modules
BulkCoExp.RdClass for applying various co-expression module detection methods on top of bulk RNAseq data.
Properties
- raw_data
A numerical matrix of the provided raw data.
- meta_data
A data.table with the meta-information about the samples.
- variable_info
An optional data.table containing the variable info.
- processed_data
A list in which various types of processed data will be stored.
- outputs
A list in which key outputs will be stored.
- params
A (nested) list that will store all the parameters of the applied function.
- final_results
A data.table that will contain the final results.