Add neighbourhood info on majority cell type
add_nhoods_info.RdThis function adds cell type composition information to the nhoods_info
slot within the miloR object. For each neighbourhood, it calculates
the proportion of the majority cell type and identifies which cell type
is most abundant. This is useful for annotating differential abundance
results with the cellular composition of each neighbourhood.