Calculates the critical value
calculate_critical_value.RdThis function calculates the critical value for a given ontology similarity matrix.
Arguments
- x
Numerical matrix or
ontology class, seeontology(). This function tends to be slower on matrices compared toontology class.- alpha
Float. The alpha value. For example, 0.001 would mean that the critical value is smaller than 0.1 percentile of the random permutations.
- permutations
Number of random permutations.
- seed
Integer. For reproducibility purposes