Calculate the information content for each ontology term
calculate_information_content.Rdthis function will calculate the information content of each
provided term based on a list of ancestors, which is a named list of terms
with ancestor identifiers as their values. Can be calculated using
get_ontology_ancestry(). The information content is calculated
as -log2(number descendant/total terms in the ontology). More information
can be found here.