Skip to contents

This function calculates the specified semantic similarities for the whole ontology and adds it to the class.

Usage

calculate_semantic_sim_onto(
  object,
  sim_type = c("resnik", "lin", "combined"),
  .verbose = TRUE
)

Arguments

object

OntologySim class. See OntologySim().

sim_type

String. One of c("resnik", "lin", "combined").

.verbose

Boolean. Controls the verbosity of the function.

Value

The class with added semantic similarities to the properties.