Calculate the Resnik or Lin semantic similarity for an ontology.
calculate_semantic_sim_onto.RdThis function calculates the specified semantic similarities for the whole ontology and adds it to the class.
Usage
calculate_semantic_sim_onto(
object,
sim_type = c("resnik", "lin", "combined"),
.verbose = TRUE
)Arguments
- object
OntologySimclass. SeeOntologySim().- sim_type
String. One of
c("resnik", "lin", "combined").- .verbose
Boolean. Controls the verbosity of the function.