Skip to contents

Can update the Scrublet thresholding after manual introspection of the histogram.

Usage

call_doublets_manual(scrublet_res, threshold, .verbose = TRUE)

Arguments

scrublet_res

ScrubletRes result class.

threshold

Numeric. The new threshold to use.

.verbose

Boolean. Controls the verbosity of the function.

Value

ScrubletRes class with updated doublet calls based on the new threshold.