Cell cycle genes
cell_cycle_genes.Rd(Human) cell cycle genes for scoring in single cell, please see
module_scores_sc() and Tirosh et al, Science (2016). These
genes are based on the updated version in Seurat.
cell_cycle_genes.Rd(Human) cell cycle genes for scoring in single cell, please see
module_scores_sc() and Tirosh et al, Science (2016). These
genes are based on the updated version in Seurat.