Iterate through different epsilon parameters
cor_module_check_epsilon.RdThis functions iterates through a set of provided epsilons and checks for each one to what extend the underlying affinity matrix will follow a power law distribution.
Arguments
- object
The class, see
BulkCoExp(). You need to runcor_module_processing()before running this function.- rbf_func
The type of RBF function you want to apply. A choice of
c('bump', 'gaussian', 'inverse_quadratic').- epsilons
Vector of floats. The different epsilon parameters you would like to run.
- .verbose
Boolean. Controls verbosity of the function.