Split CoReMo modules by correlation sign
cor_module_coremo_cor_sign.RdThis function will split the identified modules by their correlation sign.
In certain cases, positive and negatively correlated genes can be part of
the same module. This function will annotate them with "_pos" and "_neg"
respectively.
Arguments
- object
The class, see
BulkCoExp().- min_stability
Optional float. The minimum stability for the gene you wish to filter for based on the leave-one-out resampling. If
NULL, no filtering will be applied.- .verbose
Boolean. Controls verbosity of the function.