Calculate Eigengenes for CoReMo modules
cor_module_coremo_eigengene.RdThis function will calculate the eigengene values for the modules on a per sample basis and add correlations of the gene expression of a given gene within the module to its eigengene.
Arguments
- object
The class, see
BulkCoExp().- min_stability
Optional float. The minimum stability for the gene you wish to filter for based on the leave-one-out resampling. If
NULL, no filtering will be applied.- .verbose
Boolean. Controls verbosity of the function.