Prepare correlation-based module detection
cor_module_processing.RdThis function will calculate the correlation coefficients between the genes, using the highly variable genes (if available, otherwise the function will use the raw data). The data will be stored in a memory-efficient format in the properties of the class.
Usage
cor_module_processing(
object,
cor_method = c("pearson", "spearman"),
.verbose = TRUE
)Arguments
- object
The class, see
BulkCoExp(). Ideally, you should runpreprocess_bulk_coexp()before applying this function.- cor_method
String. Option of
c("pearson", "spearman").- .verbose
Boolean. Controls verbosity of the function.