Filter the calculated similarities
filter_similarities.RdThis function calculates the critical value, see
calculate_critical_value() and filters subsequently all the
term pairs to the ones with a value ≥ critical value.
Arguments
- object
OntologySimclass. SeeOntologySim().- alpha
Float. The alpha value. For example, 0.001 would mean that the critical value is smaller than 0.1 percentile of the random permutations.
- permutations
Number of random permutations.
- seed
Integer. For reproducibility purposes.
- .verbose
Boolean. Controls verbosity of the function.