Graph-based clustering of cells on the sNN graph
find_clusters_sc.RdThis function will apply Leiden clustering on the sNN graph with the given resolution and add a column to the obs table.
Arguments
- object
SingleCellsclass.- res
Numeric. The resolution parameter for
igraph::cluster_leiden().- name
String. The name to add to the obs table in the DuckDB.