Calculate DGE between two cell groups
find_markers_sc.RdThis function can be used to calculate differentially expressed genes between two groups in the single cell data. At the moment, it has only an implementation for the Wilcox-based rank statistic.
Arguments
- object
SingleCellsclass.- cells_1
String. The names of the cells in group 1. Need to be part of the cell names in the object, see
get_cell_names().- cells_2
String. The names of the cells in group 2. Need to be part of the cell names in the object, see
get_cell_names().- method
String. Which method to use for the calculations of the DGE. At the moment the only option is
"wilcox", but the parameter is reserved for future features.- alternative
String. Test alternative. One of
c("twosided", "greater", "less"). Function will default to"twosided".- min_prop
Numeric. The minimum proportion of cells that need to express the gene to be tested in any of the two groups.
- .verbose
Boolean. Controls verbosity of the function.