Skip to contents

This function will update the specified columns in the metadata of an BulkDge() or BulkCoExp() to be conform with R standard naming convetions. This is useful to do before running DGE methods as they expect standardised names.

Usage

fix_meta_data_column(object, col_names, ...)

Arguments

object

The underlying object, either BulkCoExp() or BulkDge().

col_names

Character vector. The columns to fix.

...

Additional arguments to parse to the functions.

Value

Returns the object with the respective metadata columns updated.