Calculate the proportions of reads for specific gene sets
gene_set_proportions_sc.RdThis is a helper function that calculates proportions of reads belonging to given gene sets. This can be used for example for the calculation of percentage mitochondrial reads per cell. These will be automatically added to the obs table
Arguments
- object
SingleCellsclass.- gene_set_list
A named list with each element containing the gene identifiers of that set. These should be the same as
get_gene_names(object)!- streaming
Boolean. Shall the cells be streamed in. Useful for larger data sets where you wish to avoid loading in the whole data. Default to
FALSE.- .verbose
Boolean. Controls verbosity of the function.