Get differential correlation-based graph
get_diffcor_graph.RdHelper function to get a differential correlation-based igraph from the class
Arguments
- object
The class, see
BulkCoExp().- min_cor
Float. The minimum absolute correlation that needs to be present in either data set.
- fdr_threshold
Float. The maximum FDR that is tolerated for the generation of the graph.
- .verbose
Boolean. Controls the verbosity of the function.