Skip to contents

Get the differential abundance results

Usage

get_differential_abundance_res(x)

# S3 method for class 'miloR'
get_differential_abundance_res(x)

Arguments

x

An object from which to get the differential abundance results from.

Value

The differential abundance results stored in the object if found.