General wrapper function that can be used to pull out any embedding stored
in the ScCache.
Usage
get_embedding(x, embd_name)
# S3 method for class 'ScCache'
get_embedding(x, embd_name)
Arguments
- x
An object to get embedding from
- embd_name
String. The name of the embedding to return. The function
will throw an error if the embedding does not exist.
Value
Get the specified embeddings from the object (if found).