Get the gene names based on the gene idx
get_gene_names_from_idx.RdGet the gene names based on the gene idx
Usage
get_gene_names_from_idx(x, gene_idx, rust_based = TRUE)
# S3 method for class 'ScMap'
get_gene_names_from_idx(x, gene_idx, rust_based = TRUE)
## S7 method for class <bixverse::SingleCells>
get_gene_names_from_idx(x, gene_idx, rust_based = TRUE)
## S7 method for class <bixverse::SingleCellsSubset>
get_gene_names_from_idx(x, gene_idx, rust_based = TRUE)Examples
# Rust indices translated back into gene identifiers
sc <- demo_single_cells(prepped = FALSE)
get_gene_names_from_idx(sc, gene_idx = 0:2, rust_based = TRUE)
#> 0 1 2
#> "gene_01" "gene_02" "gene_03"
unlink(sc@dir_data, recursive = TRUE, force = TRUE)