Get the gene names based on the gene idx
get_gene_names_from_idx.RdGet the gene names based on the gene idx
Get the highly variable gene indices from a SingleCells.
get_gene_names_from_idx.RdGet the gene names based on the gene idx
Get the highly variable gene indices from a SingleCells.