Skip to contents

This function loads in gene ontology data stored in the package and processes it into the format for gene_ontology_data(). Wraps load_go_human_data() and process_go_data() into one.

Usage

get_go_data_human(filter_relationships = TRUE, .verbose = TRUE)

Arguments

filter_relationships

Boolean. Shall the ontology be filtered to only "is_a" and "part_of" relationships. Defaults to TRUE.

.verbose

Boolean. Controls verbosity of the function.

Value

A data.table