Wrapper function to load and process the gene ontology data.
get_go_data_human.RdThis function loads in gene ontology data stored in the package and processes
it into the format for gene_ontology_data(). Wraps
load_go_human_data() and process_go_data() into one.