Identify the inflection point for elbow-like data
get_inflection_point.RdThis function will identify the index of the inflection point of an arbitrary
series x ~ y via the biggest increase in the first derivative. Useful to
identify key points in elbow plots.