Get the ready obs data from various sub method
get_obs_data.RdHelper method that creates data.tables with cell indices which were used in the given analysis + the values that are to be added to the obs table in the DuckDB.
get_obs_data.RdHelper method that creates data.tables with cell indices which were used in the given analysis + the values that are to be added to the obs table in the DuckDB.