Return ancestry terms from an ontology
get_ontology_ancestry.RdThis function will return all ancestors and descendants based on a provided data.table with parent-child terms
get_ontology_ancestry.RdThis function will return all ancestors and descendants based on a provided data.table with parent-child terms