Returns the available features for single cell applications
get_sc_available_features.RdReturns a data.table with available features in the obs table and in the count matrices.
get_sc_available_features.RdReturns a data.table with available features in the obs table and in the count matrices.