Prepare class for ICA
ica_processing.RdThis is the generic function for doing the necessary preprocessing for running independent component analysis.
Arguments
- object
The class, see
BulkCoExp(). Ideally, you should runpreprocess_bulk_coexp()before applying this function.- fast_svd
Boolean. Shall randomised SVD be used for the whitening. This is faster and usually causes little precision loss.
- random_seed
Integer. Seed for the randomised SVD. Only relevant, if fast_svd =
TRUE.- .verbose
Boolean. Controls verbosity of the function.