Skip to contents

Helper function that can load the parameters to access the on-disk stored data into the class.

Usage

load_existing(object)

Arguments

object

SingleCells class.

Value

The object with added information on the data on disk.