load_existing.Rd
Helper function that can load the parameters to access the on-disk stored data into the class.
load_existing(object)
SingleCells class.
SingleCells
The object with added information on the data on disk.