Get the Gene Ontology data human
load_go_human_data.RdThis function loads in gene ontology data stored in the package. This is for humans only.
load_go_human_data.RdThis function loads in gene ontology data stored in the package. This is for humans only.