Normalise the count data for DGE.
normalise_bulk_dge.RdThis function will apply the CPM + Voom normalisation and can additionally calculate TPM and FPKM values for plotting purposes.
Usage
normalise_bulk_dge(
object,
group_col,
norm_method = c("TMM", "TMMwsp", "RLE", "upperquartile", "none"),
calc_tpm = FALSE,
calc_fpkm = FALSE,
gene_lengths = NULL,
.verbose = TRUE
)Arguments
- object
The underlying class, see
BulkDge().- group_col
String. The column in the metadata that will contain the contrast groups. Needs to be part of the metadata stored in the class.
- norm_method
String. One of
c("TMM", "TMMwsp", "RLE", "upperquartile", "none"). Please refer toedgeR::normLibSizes().- calc_tpm
Boolean. Output TPM calculation (default = FALSE).
- calc_fpkm
Boolean. Output FPKM calculation (default = FALSE).
- gene_lengths
Optional named numeric. If you want to calculate TPM or FPKM you need to provide this one. The names need to be the same identifier as used in the counts.
- .verbose
Boolean. Controls the verbosity of the function.