Calculates a harmonic sum normalised between 0 to 1.
ot_harmonic_score.RdThe function takes in a vector of scores between 0 and 1 and calculates a harmonic sum, based on the approach OpenTargets takes to do their gene - disease evidence scores, see: https://platform-docs.opentargets.org/associations.
The function takes in a vector of scores between 0 and 1 and calculates a harmonic sum, based on the approach OpenTargets takes to do their gene - disease evidence scores, see: https://platform-docs.opentargets.org/associations.