Wrapper function for graph generation
params_cor_graph.RdWrapper function for graph generation
Arguments
- epsilon
Float. Defines the epsilon parameter for the radial basis function. Defaults to 2, but should be ideally optimised.
- min_cor
Float. Minimum absolute correlation that needs to be observed in either data set. Only relevant for differential correlation-based graphs.
- fdr_threshold
Float. Maximum FDR for the differential correlation p-value.
- verbose
Boolean. Controls verbosity of the graph generation function.