Wrapper function for ICA randomisation
params_ica_randomisation.RdWrapper function for ICA randomisation
Arguments
- cross_validate
Boolean. Do you want to apply a cross-validation type approach and split the data into
foldsfolds to assess within data stability of the component. Defaults toFALSE.- random_init
Integer. Number of random initialisations to use. Defaults to
50L.- folds
Integer. Number of folds to use if
cross_validateis set toTRUE. To note, you will be runningrandom_init * foldsICA runs. Defaults to10L.
Value
A named list with the following elements:
cross_validate - Boolean. Do you want to apply a cross-validation type approach and split the data into
foldsfolds to assess within data stability of the component. Defaults toFALSE.random_init - Integer. Number of random initialisations to use. Defaults to
50L.folds - Integer. Number of folds to use if
cross_validateis set toTRUE. To note, you will be runningrandom_init * foldsICA runs. Defaults to10L.