Helper function to generate default parameters for PCA
params_pca_defaults.RdHelper function to generate default parameters for PCA
Value
A list with the following parameters for PCA.
no_pcs - Integer. Number of PCs to consider. Defaults to
30L.random_svd - Boolean. Shall randomised SVD be used. Defaults to
TRUE.sparse - Boolean. Shall sparse solvers be used that do not do scaling. If set to yes, in the case of
random_svd = FALSE, Lanczos iterations are used to solve the sparse SVD. Withrandom_svd = TRUE, the sparse initial matrix is multiplied with the random matrix, yielding a much smaller dense matrix that does not increase the memory pressure massively.