Constructor for SCENIC parameters
params_scenic.RdConstructor for SCENIC parameters
Arguments
- min_counts
Integer. Minimum total counts a gene needs to be included in the analysis. Defaults to
50L.- min_cells
Numeric. Minimum proportion of cells (between 0 and 1) that must express a gene for it to be considered. Defaults to
0.03.- learner_type
String. Regression learner to use. One of
c("randomforest", "extratrees", "grnboost2"). Defaults to"randomforest".- gene_batch_strategy
String. Strategy for grouping target genes into batches. Only used for
"randomforest"and"extratrees"learners; ignored for"grnboost2". One ofc("correlated", "random"). Defaults to"correlated".- gene_batch_size
Integer or
NULL. Number of genes per batch. IfNULL(default), the batch size is determined automatically. Ignored for"grnboost2". Defaults toNULL.- n_pcs
Integer. Number of PCs to use for the correlated gene batch strategy. Defaults to
50L.- n_subsample
Integer. Cell subsampling threshold for the correlated gene batch strategy. If the number of cells meets or exceeds this value,
n_subsamplecells are randomly selected prior to running randomised SVD. Defaults to100000L.- learner_params
List. Optional overrides for the regression learner parameters. For
"randomforest", seeparams_scenic_random_forest_defaults(). For"extratrees", seeparams_scenic_extra_trees_defaults(). For"grnboost2", seeparams_scenic_gradient_boosting_defaults(). Defaults tolist().
Value
A named list with the following elements:
min_counts - Integer. Minimum total counts a gene needs to be included in the analysis. Defaults to
50L.min_cells - Numeric. Minimum proportion of cells (between 0 and 1) that must express a gene for it to be considered. Defaults to
0.03.learner_type - String. Regression learner to use. One of
c("randomforest", "extratrees", "grnboost2"). Defaults to"randomforest".gene_batch_strategy - String. Strategy for grouping target genes into batches. Only used for
"randomforest"and"extratrees"learners; ignored for"grnboost2". One ofc("correlated", "random"). Defaults to"correlated".gene_batch_size - Integer or
NULL. Number of genes per batch. IfNULL(default), the batch size is determined automatically. Ignored for"grnboost2". Defaults toNULL.n_pcs - Integer. Number of PCs to use for the correlated gene batch strategy. Defaults to
50L.n_subsample - Integer. Cell subsampling threshold for the correlated gene batch strategy. If the number of cells meets or exceeds this value,
n_subsamplecells are randomly selected prior to running randomised SVD. Defaults to100000L.The elements of the base list, overridden by
learner_params, spliced in at this position.