Skip to contents

Plots the epsilon results (if they can be found in the class). The x-axis reflects the different epsilon parameters for the radial basis function, and the y-axis the R2 value that the resulting networks follows a power law distribution (i.e., scale free topology).

Usage

plot_epsilon_res(object)

Arguments

object

The class, see BulkCoExp().

Value

If epsilon results were found, returns the ggplot. Otherwise, throws a warning and returns NULL.