Plot the epsilon vs. power law goodness of fit result
plot_epsilon_res.RdPlots the epsilon results (if they can be found in the class). The x-axis reflects the different epsilon parameters for the radial basis function, and the y-axis the R2 value that the resulting networks follows a power law distribution (i.e., scale free topology).
Arguments
- object
The class, see
BulkCoExp().