plot_rbf_impact.Rd
This function plots the distance to affinity relationship after applying a given radial basis function (RBF) with a given epsilon value.
plot_rbf_impact(rbf_type, epsilon)
String. The RBF type. One of c("gaussian", "bump", "inverse_quadratic")
c("gaussian", "bump", "inverse_quadratic")
Numerical. The epsilon parameter.
A plot depicting the distance to affinity relationship after applying the RBF function.