Process Gene Ontology data into the right format
process_go_data.RdHelper function that takes in different files containing gene ontology data and puts them together for various gene set enrichment methods using the ontological information
Value
data.table ready for usage in gene_ontology_data().