Read summary statistics from the X slot of an h5ad file
read_h5ad_x_summary.RdRead summary statistics from the X slot of an h5ad file
Value
A list with:
stats - named vector: min, max, mean, median, and fraction of values that are whole numbers
is_integer_valued - logical; TRUE if >99% of sampled non-zero values are whole numbers
type - "CSR" or "CSC"
dims - named integer vector c(obs, var)
sample - numeric vector of sampled non-zero values