Skip to contents

This function allows to remove certain samples from the object

Usage

remove_samples(object, samples_to_remove, ...)

Arguments

object

The underlying object, either BulkCoExp() or BulkDge().

samples_to_remove

Character vector. The sample identifiers to remove.

...

Additional arguments to parse to the functions.

Value

Returns the object with the samples removed. This will regenerated the object from the start and remove any data in it.