Generate a vector-based representation of the upper triangle of a matrix
rs_dense_to_upper_triangle.Rd
This function generates a vector from the upper triangle of a given
symmetric matrix, iterating through the rows. You have the option to
remove the diagonal with setting
shift = TRUE.