Generate a vector-based representation of the upper triangle of a matrix
rs_dense_to_upper_triangle.RdThis function generates a vector from the upper triangle of a given symmetric matrix. You have the option to remove the diagonal with setting shift to 1.