Calculate the column wise differential correlation between two sets of data.
rs_differential_cor.Rd
This function calculates the differential correlation based on the Fisher
method. For speed purposes, the function will only calculate the
differential correlation on the upper triangle of the two correlation
matrices.
Value
A list containing, one entry per upper-triangle feature pair:
r_a - The correlation coefficients in the upper triangle of matrix a.
r_b - The correlation coefficients in the upper triangle of matrix b.
z_score - The z-scores of the difference in correlation coefficients.
p_val - The z-scores transformed to two-sided p-values.