rs_filter_onto_sim.Rd
This function takes the similarity values as the upper triangle, the row/column names and filtering the values down based on the threshold.
rs_filter_onto_sim(sim_vals, names, threshold)
Numerical vector. The upper triangle of the similarity matrix as a flattened vector.
String vector. The row/col names of the similarity matrix.
Float. The filtering threshold.
A list with:
t1 - name of term 1.
t2 - name of term 2.
sim - the similarity between the two terms.