Rust version of the GSVA algorithm
rs_gsva.RdRust-based implementation of the popular GSVA algorithm. Has further performance optimisations compared to the original implementation.
Arguments
- exp
Numerical matrix. The expression matrix with rows = genes, and columns = samples
- gs_list
List. A list containing the indices of the pathway genes (needs to be null indexed). See
rs_prepare_gsva_gs().- tau
Float. Tau parameter, usual recommendation is to use
1.0here. Larger values emphasise the tails more.- gaussian
Boolean. If
TRUEthe Gaussian kernel will be used, ifFALSEthe Poisson kernel will be used.- max_diff
Boolean. Scoring mode:
TRUE= difference,FALSE= larger absolute value- abs_rank
Booelan. If
TRUE= pos-neg,FALSE= pos+neg- timings
Boolean. Prints timings from the algorithm.