Calculate gene<>gene spatial correlations
rs_hotspot_gene_cor.RdThis function implements the HotSpot gene <> gene local correlation functionality from HotSpot, see DeTomaso, et al.
Usage
rs_hotspot_gene_cor(
f_path_genes,
f_path_cells,
embd,
hotspot_params,
cells_to_keep,
genes_to_use,
streaming,
verbose,
seed
)Arguments
- f_path_genes
Path to the
counts_genes.binfile.- f_path_cells
Path to the
counts_cells.binfile.- embd
Numerical matrix. The embedding matrix from which to generate the kNN graph.
- hotspot_params
List. The HotSpot parameter list.
- cells_to_keep
Integer vector. 0-index vector indicating which cells to include in the analysis. Ensure that this is of same order/length as the embedding matrix.
- genes_to_use
Integer vector. 0-index vector indicating which genes to include.
- streaming
Boolean. Shall the data be streamed in chunks. Useful for large data sets.
- verbose
Boolean. Controls verbosity of the function.
- seed
Integer. Random seed for reproducibility.