Calculate AUCell in Rust (for meta cells)
rs_mc_aucell.Rd
The function will take in a list of gene set indices (0-indexed!) and
calculate an AUCell type statistic. Three options here: the recovery-curve
AUC of Aibar, et al. (the actual AUCell statistic), an AUC derived from the
Mann-Whitney statistic, or average precision. This version works on
MetaCell counts which are stored in memory directly. Genes are ranked
within each meta cell on the second layer, an
f32 cast of the supplied
counts.
Arguments
- sparse_data
A named list that needs to have
data,indptr,indices,nrow,ncolandcs_type. Shape is (metacells, genes).- gs_list
List. List with the gene set indices (0-indexed!) of the genes of interest.
- aucell_params
List. The AUCell parameters, see
params_sc_aucell().- verbose
Integer.
0L- quiet;1L- normal verbosity;2L- detailed verbosity.