Calculates the mutual information matrix
rs_mutual_info.RdArguments
- x
R matrix with doubles for which to calculate the mutual information
- n_bins
Optional integer. Number of bins to use. If
NULLis provided the function will default tosqrt(nrow(x)).- strategy
String. Binning strategy. One of
c("equal_width", "equal_freq"). Unknown strings default to"equal_width".- normalise
Boolean. Shall the normalised mutual information be calculated via joint entropy.