Skip to contents

Calculates the mutual information across all columns in the data.

Usage

rs_mutual_info(x, n_bins, strategy, normalise)

Arguments

x

R matrix with doubles for which to calculate the mutual information

n_bins

Optional integer. Number of bins to use. If NULL is provided the function will default to sqrt(nrows(x)).

strategy

String. Binning strategy One of c("equal_width", "equal_freq"). If weird string is provided, it will default to "equal_width".

normalise

Boolean. Shall the normalised mutual information be calculated via joint entropy.

Value

The mutual information matrix.