Calculates the mutual information matrix
rs_mutual_info.RdCalculates the mutual information across all columns in the data.
Arguments
- x
R matrix with doubles for which to calculate the mutual information
- n_bins
Optional integer. Number of bins to use. If
NULLis provided the function will default tosqrt(nrows(x)).- strategy
String. Binning strategy One of
c("equal_width", "equal_freq"). If weird string is provided, it will default to"equal_width".- normalise
Boolean. Shall the normalised mutual information be calculated via joint entropy.