Run randomised SVD over a matrix
rs_random_svd.RdRuns a randomised singular value decomposition over a matrix. This implementation is faster than the full SVD on large data sets, with slight loss in precision.
Arguments
- x
Numeric matrix. Rows = samples, columns = features.
- rank
Integer. The rank to use.
- seed
Integer. Random seed for reproducibility.
- oversampling
Integer. Defaults to
10Lif nothing is provided.- n_power_iter
Integer. How often shall the QR decomposition be applied. Defaults to
2Lif nothing is provided.