rs_rank_matrix_col.Rd
Ranks the columns of a matrix with the tie method.
rs_rank_matrix_col(exp)
Numerical matrix. The expression matrix (rows = genes, columns = samples).
Returns a matrix of ranks with the same shape as exp.
exp