Generate reciprocal best hits based on correlations
rs_rbh_cor.RdThis function takes list of (named) matrices which represent for example matrix factorisation results you wish to identify reciprocal best hits (RBH) for. The rows need to represent the features and the columns the parts you wish to calculate the RBH for.
Value
A list containing:
origin - The name of the origin of the gene modules.
target - The name of the target of the gene modules.
comparisons - Integer vector indicating how many RBH hits were identified in this comparison
origin_modules - Names of the gene modules from the origin.
target_modules - Names of the gene modules from the target.
similarity - The similarities between the two respective gene modules.