Detect Doublets via BoostClassifier (in Rust)
rs_sc_doublet_detection.RdDetect Doublets via BoostClassifier (in Rust)
Usage
rs_sc_doublet_detection(
f_path_gene,
f_path_cell,
cells_to_keep,
boost_params,
seed,
streaming,
verbose
)Arguments
- f_path_gene
String. Path to the
counts_genes.binfile.- f_path_cell
String. Path to the
counts_cells.binfile.- cells_to_keep
Integer vector. The indices (0-indexed!) of the cells to include in this analysis.
- boost_params
List. Parameter list, see
params_boost().- seed
Integer. Seed for reproducibility purposes.
- streaming
Boolean. Shall the data be streamed for the HVG calculations.
- verbose
Boolean. Controls verbosity
Value
A list with
predicted_doublets - Boolean vector indicating which observed cells predicted as doublets (TRUE = doublet, FALSE = singlet).
doublet_scores_obs - Numerical vector with the likelihood of being a doublet for the observed cells.
voting_avg - Voting average across the different iterations.