Generates the kNN graph with additional distances
rs_sc_knn_w_dist.RdThis function is a wrapper over the Rust-based generation of the approximate nearest neighbours.
Arguments
- embd
Numerical matrix. The embedding matrix to use to generate the kNN graph.
- knn_params
List. The kNN parameters defined by
params_sc_neighbours().- verbose
Boolean. Controls verbosity of the function and returns how long certain operations took.
- seed
Integer. Seed for reproducibility purposes.