Generates the sNN graph for igraph
rs_sc_snn.RdThis function takes a kNN matrix and generates the inputs for an SNN graph based on it.
Arguments
- knn_mat
Integer matrix. Rows represent cells and the columns represent the neighbours.
- snn_method
String. Which method to use to calculate the similarity. Choice of
c("jaccard", "rank").- limited_graph
Boolean. Shall the sNNs only be calculated between direct neighbours in the graph, or between all possible combinations.
- pruning
Float. Below which value for the Jaccard similarity to prune the weight to 0.
- verbose
Boolean. Controls verbosity of the function.