SCENIC: Generating gene-regulatory networks (streaming version)
rs_scenic_grn_streaming.RdLoads the genes in as chunks to avoid high memory pressure.
Usage
rs_scenic_grn_streaming(
f_path_genes,
cell_indices,
gene_indices,
tf_indices,
scenic_params,
seed,
verbose
)Arguments
- f_path_genes
Path to the
counts_genes.binfile.- cell_indices
Integer vector. 0-indexed(!) positions of cells to include in the analysis
- gene_indices
Integer vector. 0-indexed(!) positions of the genes to include.
- tf_indices
Integer vector. 0-indexed(!) positions of the TF predictor variables to use in the generation of the regression learners.
- scenic_params
Named list. Contains all of the parameters need for SCENIC.
- seed
Integer. Controls reproducibility of the function.
- verbose
Boolean. Controls the verbosity of the function.