Set similarities
rs_set_similarity.RdThis function calculates the Jaccard or similarity index between a two given string vector and a of other string vectors.
rs_set_similarity.RdThis function calculates the Jaccard or similarity index between a two given string vector and a of other string vectors.