Rust version of the ssGSEA algorithm
rs_ssgsea.RdRust-based implementation of the popular single sample GSEA algorithm. Has further performance optimisations compared to the original implementation.
Arguments
- exp
Numerical matrix. The expression matrix with rows = genes, and columns = samples
- gs_list
List. A list containing the indices of the pathway genes (needs to be null indexed). See
rs_prepare_gsva_gs().- alpha
Float. The alpha parameter to adjust the weights.
- normalise
Boolean. Shall the scores be normalised.
- timings
Boolean. Prints timings from the algorithm.