Generate synthetic single cell data (h5ad type)
rs_synthetic_sc_data_csr.RdThis function generates pseudo data to test single cell functions in form of the h5ad version, with cells = rows and genes = columns. The data is encoded in CSR.
Arguments
- n_genes
Integer. Number of genes you wish to have in the synthetic data.
- n_cells
Integer. Number of cells you wish to have in the synthetic data.
- min_genes
Integer. Minimum number of genes expressed per cell.
- max_genes
Integer. Maximum number of genes expressed per cell.
- max_exp
Upper bound in terms of expression. Expression values will be sampled from
1:max_exp.- seed
Integer. Seed for reproducibility purposes.