Calculate VISION pathway scores in Rust
rs_vision.RdThe function will take in a list of gene sets that contains lists of "pos"
and "neg" gene indices (0-indexed). You don't have to provide the "neg",
but it can be useful to classify the delta of two stats (EMT, Th1; Th2) etc.
Arguments
- f_path
String. Path to the
counts_cells.binfile.- gs_list
Nested list. Each sublist contains the (0-indexed!) positive and negative gene indices of that specific gene set.
- cells_to_keep
Integer. Vector of indices of the cells to keep.
- streaming
Boolean. Shall the data be streamed.
- verbose
Boolean. Controls verbosity of the function.