Skip to contents

Add multiple new columns to the obs table

Usage

set_sc_new_obs_col_multiple(object, new_data)

Arguments

object

bixverse::SingleCells class.

new_data

Named list. The names will be the column names and the elements will be added to the obs table. Needs to be of same length as get_cells_to_keep() and have the same order!

Value

The class with updated obs table in the DuckDB