Add multiple new columns to the obs table
set_sc_new_obs_col_multiple.RdAdd multiple new columns to the obs table
Arguments
- object
bixverse::SingleCellsclass.- new_data
Named list. The names will be the column names and the elements will be added to the obs table. Needs to be of same length as
get_cells_to_keep()and have the same order!