Pipeline step: identify highly variable genes
step_hvg_sc.RdWraps find_hvg_sc() as an ScStep.
Usage
step_hvg_sc(
hvg_no = 2000L,
hvg_params = params_sc_hvg(),
streaming = NULL,
.verbose = TRUE
)Arguments
- hvg_no
Integer. Number of highly variable genes to include. Defaults to
2000L.- hvg_params
List, see
params_sc_hvg(). This list containsmethod - Which method to use. One of
c("vst", "meanvarbin", "dispersion")loess_span - The span for the loess function to standardise the variance
num_bin - Integer. Not yet implemented.
bin_method - String. One of
c("equal_width", "equal_freq"). Not implemented yet.
- streaming
Optional Boolean. Shall the data be streamed in. Useful for larger data sets where you wish to avoid loading in the whole data. If
NULL, will automatically detect. Not used forMetaCells.- .verbose
Boolean or integer. Controls verbosity and returns run times.
FALSE-> quiet,TRUEor1L-> normal verbosity,2L-> detailed verbosity.