Generates synthetic data for contrastive PCA exploration.
synthetic_c_pca_data.RdGenerates three elements: target matrix, background matrix and labels for the target matrix.
synthetic_c_pca_data.RdGenerates three elements: target matrix, background matrix and labels for the target matrix.