Diffuse seed genes in a tied manner over a network
tied_diffusion.RdThis function takes two sets of diffusion vector and leverages tied diffusion to identify an intersection of influential nodes. If the network is undirected, the method will run two personalised page rank diffusions based on the diffusion vectors and generate the score aggregation
Arguments
- object
NetworkDiffusionsobject. The underlying classNetworkDiffusions().- diffusion_vector_1
Named numeric. The first named vector with values to use for the reset parameter in the personalised page-rank diffusion. Names should represent node names of the graph.
- diffusion_vector_2
Named numeric. The second named vector with values to use for the reset parameter in the personalised page-rank diffusion. Names should represent node names of the graph.
- summarisation
String. If there are duplicated names in the
diffusion_vectorhow to summarise these.- score_aggregation
String. How to summarise the tied scores.
- .verbose
Boolean. Controls verbosity of the function.