Calculate the proportions of reads for the Top N genes
top_genes_perc_sc.RdThis is a helper function that calculates proportions of reads to the Top N genes by expression in a given cell. High values here can indicate low complexity, quality cells. The values will be automatically added to the obs table.
Usage
top_genes_perc_sc(
object,
top_n_vals = c(25L, 50L, 100L),
streaming = FALSE,
.verbose = TRUE
)