Replace values in a metadata column
update_metadata_values.RdThis function will update the values in a given metadata column based on what you are providing in terms of replacement.
Arguments
- object
The underlying object, either
BulkCoExp()orBulkDge().- column
Character vector. The columns for which to replace the values.
- replacement
Named character vector. The values with which to replace the data.
- ...
Additional arguments to parse to the functions.