Calculate VISION scores
vision_sc.RdCalculates an VISION-type scores for pathways based on DeTomaso, et al. Compared to other score types, you can also calculate delta-type scores between positive and negative gene indices, think epithelial vs mesenchymal gene signature, etc.
Arguments
- object
SingleCellsclass.- gs_list
Named nested list. The elements have the gene identifiers of the respective gene sets and have the option to have a
"pos"and"neg"gene sets. The names need to be part of the variables of theSingleCellsclass.- streaming
Boolean. Shall the cell data be streamed in. Useful for larger data sets.
- .verbose
Boolean. Controls the verbosity of the function.